@@ -139,7 +139,9 @@ class Data(object):
         return Data.Base_pool[base_id].query(sql, show_sql) if base_id in Data.Base_pool else None
 
     @staticmethod
-    def get_cache(table,is_safe=True):
+    def get_cache(table,safe=True):
+        if safe:
+            pass
         res = {}
         all_data = Data.select(table,[])
         for i in all_data:
